@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Mojolicious::Plugin::Pubsub;
 #ABSTRACT: Pubsub plugin for Mojolicious
-$Mojolicious::Plugin::Pubsub::VERSION = '0.002';
+$Mojolicious::Plugin::Pubsub::VERSION = '0.003';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use Mojo::IOLoop;
@@ -17,7 +17,7 @@ sub register {
 
   $cfg->{cbs} = [];
   push @{ $cfg->{subs} }, $cfg->{cb} if exists $cfg->{cb};
-  $cfg->{socket} = $app->moniker . '.pubsub' unless exists $cfg->{socket};
+  $cfg->{socket} = $app->home->child($app->moniker . '.pubsub') unless exists $cfg->{socket};
   $conf = $cfg;
 
   my $loop = Mojo::IOLoop->singleton;
@@ -194,7 +194,7 @@ Mojolicious::Plugin::Pubsub - Pubsub plugin for Mojolicious
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -222,7 +222,7 @@ Takes a callback C<CODE> reference.
 
 =head2 socket
 
-A path to a C<UNIX> socket used to communicate between the publishers. By default this will be C<< $app->moniker . '.pubsub' >>.
+A path to a C<UNIX> socket used to communicate between the publishers. By default this will be C<< $app->home->child($app->moniker . '.pubsub') >>.
 
 =head1 HELPERS
 
